%global snapshot 10505

# Define a macro for calling configure from inside autotools directory
%global dconfigure %(printf %%s '%configure' | sed 's!\./configure!autotools/configure!g')

Name:  libpwiz
Summary: ProteoWizard software library
Version: 3.0.%{snapshot}
Release: 2%{?dist}

# MPLv2.0 and LGPLv2+ and BSD are licenses used for eigen/* files
License: ASL 2.0 and zlib and MPLv2.0 and LGPLv2+ and BSD
URL:   http://proteowizard.sourceforge.net

##Source archive downloaded from http://proteowizard.sourceforge.net/downloads.shtml
##Chose "Source, GNU Autotools build, No 2rd party reader support"
Source0: libpwiz_src_3_0_%{snapshot}.tgz

##File for testing directly downloaded from
##http://sourceforge.net/p/proteowizard/code/HEAD/tree/trunk/pwiz/example_data/tiny.pwiz.1.1.1.mzML
Source1: libpwiz-tiny.pwiz.1.1.1.mzML

##Source archive downloaded from http://proteowizard.sourceforge.net/downloads.shtml
##svn checkout https://svn.code.sf.net/p/proteowizard/code/trunk/pwiz/libraries/Eigen eigen
# rm -rf eigen/.svn
#
## See bug https://sourceforge.net/p/proteowizard/bugs/13/
Source2: eigen-nnls.tar.xz

BuildRequires:  make 
BuildRequires:  gcc-c++
BuildRequires:  coreutils
BuildRequires:  findutils
BuildRequires:  sed
BuildRequires:  boost-devel
BuildRequires:  fftw-devel
BuildRequires:  gd-devel
BuildRequires:  libtool
BuildRequires:  intltool
BuildRequires:  libsvm-devel
BuildRequires:  libzip-devel
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  dos2unix
BuildRequires:  doxygen

# Non-Negagive Least Squares Algorithm for Eigen
Provides: bundled(eigen3-nnls)

%description
The ProteoWizard Library and Tools are a set of modular and
extensible open-source, cross-platform tools and
software libraries that facilitate proteomics data analysis.

%package devel
Summary: The %{name} development-related files
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
%description devel
%{name} unversioned shared file.

%package tools
Summary: ProteoWizard software tools
Requires: %{name}%{?_isa} = %{version}-%{release}
%description tools
ProteoWizard software tools:

 idconvert - Reads diverse peptide identification formats and outputs to
             mzIdentML (or other things)
 mscat     - Exports data from a variety of formats into 4 column text format
 msconvert - General data format conversion tool
 txt2mzml  - Converts data from 4 column format to mzML

%package doc
Summary: ProteoWizard HTML documentation
BuildArch: noarch

%description doc
ProteoWizard HTML documentation.

%prep
%setup -q -n pwiz
tar -xvf %{SOURCE2}

install -pm 755 %{SOURCE1} .

##Remove spurious executable permissions
##Convert file in Dos format to Unix
for i in `find . -type f \( -name "*.cpp" -o -name "*.hpp" \)`; do
chmod a-x $i
dos2unix $i
done

##Remove bundled files
rm -f libraries/libsvm-3.0/svm.h
sed -e 's|-I"./libraries/libsvm-3.0"||g' -i autotools/Makefile.am

##Replace obsoleted m4 macros
sed -e 's|AM_CONFIG_HEADER|AM_CONFIG_HEADERS|g' -i autotools/aclocal.m4
sed -e 's|AC_PROG_LIBTOOL|LT_INIT|g' -i autotools/configure.ac autotools/configure

pushd autotools
autoreconf -ivf
popd

%build
%dconfigure --disable-static-boost --with-boost
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

# Parallel make is damaging
make -j1 \
 CPPFLAGS=" -pthread -I%{_includedir}/libsvm -I./eigen -I./libraries/CSpline" \
 CXXFLAGS="%{optflags} -Wl,-z,relro -Wl,-z,now -I./eigen -I./libraries/CSpline" \
 LDFLAGS="%{__global_ldflags} -Wl,-z,now -Wl,--as-needed -L%{_libdir} -lsvm" \
 BOOST_LDPATH=%{_libdir}

pushd doc/dox
doxygen
popd

%install
%make_install

##Remove Example executable files, static lib, libtool archive
rm -f %{buildroot}%{_bindir}/*_example_*
rm -f %{buildroot}%{_bindir}/hello_*
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/*.la

# Install header files and clean
mkdir -p %{buildroot}%{_includedir}
cp -a pwiz %{buildroot}%{_includedir}
cp -a eigen %{buildroot}%{_includedir}/pwiz/

pushd %{buildroot}%{_includedir}/pwiz
for i in `find . -type f \( -name "*.cpp" -o -name "*.*o" \)`; do
 rm -f $i
done
for i in `find . -type d -name '.[^.]*'`; do
 rm -rfd $i
done
for i in `find . -type f -name '.dirstamp'`; do
 rm -f $i
done
popd

%check
./msconvert libpwiz-tiny.pwiz.1.1.1.mzML -v -o output --zlib \
 --mzXML --%{__isa_bits} --mz%{__isa_bits} --inten%{__isa_bits}
./msconvert libpwiz-tiny.pwiz.1.1.1.mzML -v -o output \
 --mzXML --%{__isa_bits} --mz%{__isa_bits} --inten%{__isa_bits} 

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc NOTICE autotools/AUTHORS autotools/NEWS
%license LICENSE
%{_libdir}/libpwiz.so.*

%files devel
%{_libdir}/libpwiz.so
%{_includedir}/pwiz/

%files tools
%{_bindir}/idconvert
%{_bindir}/mscat
%{_bindir}/msconvert
%{_bindir}/pepcat
%{_bindir}/txt2mzml

%files doc
%doc doc/dox/html NOTICE autotools/AUTHORS autotools/NEWS
%license LICENSE

%changelog
* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.10505-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 25 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.0.10505-1
- Update to the snapshot 10505
- Provide bundled(eigen3-nnls)

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.10422-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Feb 07 2017 Antonio Trande <sagitterATfedoraproject.org> - 3.0.10422-1
- Update to the snapshot 10422

* Thu Sep 22 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.0.9992-2
- Remove hidden directories from _includedir

* Thu Sep 22 2016 Antonio Trande <sagitterATfedoraproject.org> - 3.0.9992-1
- Update to 9992
- Install header files
- Build html documentation

* Tue May 17 2016 Jonathan Wakely <jwakely@redhat.com> - 3.0.9393-2
- Rebuilt for linker errors in boost (#1331983)

* Thu Mar 03 2016 Antonio Trande <sagitterATfedoraproject.org> 3.0.9393-1
- Update to snapshot 9393

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.9283-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild 

* Mon Jan 25 2016 Antonio Trande <sagitterATfedoraproject.org> 3.0.9283-3
- Fixed test error

* Sat Jan 23 2016 Antonio Trande <sagitterATfedoraproject.org> 3.0.9283-2
- Rebuild for Boost-1.60

* Wed Jan 13 2016 Antonio Trande <sagitterATfedoraproject.org> 3.0.9283-1
- Update to release 9283
- Fixed License

* Fri Dec 18 2015 Antonio Trande <sagitterATfedoraproject.org> 3.0.9205-2
- Tested msconvert tool

* Mon Dec 14 2015 Antonio Trande <sagitterATfedoraproject.org> 3.0.9205-1
- First package
